GRO structure file format — GromacsWrapper 0.4.0-dev documentation

### Navigation

- index
- modules |
- GromacsWrapper 0.4.0-dev documentation »

# GRO structure file format

Not implemented.

..SeeAlso:: MDAnalysis has a working Python GRO reader.

class `gromacs.fileformats.gro.` `GRO`(**kwargs)

  Class that represents a GROMOS (gro) structure file.

  File format:

  `read`(filename=None)

    Read and parse index file filename.

### Navigation

- index
- modules |
- GromacsWrapper 0.4.0-dev documentation »